use chrono::{DateTime, Local, NaiveDateTime, Utc};
use dioxus::prelude::*;

use crate::page::supply::CloseXButton;

#[component]
pub fn HeaderTitle(title: String) -> Element {
    rsx! {
        h1 {
            class: "text-3xl font-bold mb-6",
            {title}
        },
    }
}

#[component]
pub fn TransientHeader(title: String) -> Element {
    rsx! {
        h1 {
            class: "flex text-2xl font-semibold border-b border-neutral-200 dark:border-neutral-700 pb-4",
            CloseXButton {  }
            {title}
        }
    }
}

#[component]
pub fn BasicButton(title: String, onclick: EventHandler<MouseEvent>) -> Element {
    rsx! {
        div {
            class: "mt-4",
            button {
                class: "\
                    inline-flex items-center gap-2 px-4 py-2 rounded-md \
                    bg-blue-600 hover:bg-blue-700 dark:bg-blue-500 dark:hover:bg-blue-600 \
                    text-white text-sm font-medium shadow-sm hover:shadow-md transition-all duration-200 cursor-pointer",
                onclick: onclick,
                {title}
            }
        }
    }
}

#[component]
pub fn LabeledInput(label: String, children: Element) -> Element {
    rsx! {
        div {
            class: "flex flex-col gap-1",
            label { class: "text-sm font-medium", {label} }
            {children}
        }
    }
}

pub fn to_human_date(unix_ts: i64) -> String {
    let naive = NaiveDateTime::from_timestamp(unix_ts, 0);
    let datetime_utc: DateTime<Utc> = DateTime::from_utc(naive, Utc);
    let datetime_local: DateTime<Local> = DateTime::from(datetime_utc);

    let now = Local::now();
    let duration = now.signed_duration_since(datetime_local);

    // Format the date part
    let date_str = datetime_local.format("%Y-%m-%d %H:%M").to_string();

    // Format the delta part
    let ago_str = if duration.num_seconds() < 60 {
        "just now".to_string()
    } else if duration.num_minutes() < 60 {
        format!(
            "{} minute{} ago",
            duration.num_minutes(),
            if duration.num_minutes() != 1 { "s" } else { "" }
        )
    } else if duration.num_hours() < 24 {
        format!(
            "{} hour{} ago",
            duration.num_hours(),
            if duration.num_hours() != 1 { "s" } else { "" }
        )
    } else {
        format!(
            "{} day{} ago",
            duration.num_days(),
            if duration.num_days() != 1 { "s" } else { "" }
        )
    };

    format!("{} ({})", date_str, ago_str)
}
