use dioxus::prelude::*;
use dioxus_material_icons::MaterialIcon;

use crate::{page::HeaderTitle, TransactionCard};

/// Home Page
#[component]
pub fn Home() -> Element {
    let min = use_resource(move || async move { crate::api::API::get_items_under_min().await });
    let expired = use_resource(move || async move { crate::api::API::get_expired_items().await });
    let global = use_resource(move || async move { crate::api::API::get_global_item_stat().await });

    rsx! {
        div {
            HeaderTitle { title: "Home" }

            div {
                id: "column",
                class: "space-y-6",

                match &*global.read_unchecked() {
                    Some(resp) => rsx! {
                        div {
                            id: "card",
                            class: "\
                                w-full flex items-center justify-between bg-white dark:bg-neutral-800 \
                                shadow-md rounded-xl p-5",

                            // Items
                            div {
                                class: "flex items-center gap-3",
                                MaterialIcon {
                                    name: "inventory_2",
                                    size: 24
                                },
                                p {
                                    class: "text-md font-medium",
                                    {format!("Items: {}", resp.item_count)}
                                }
                            },

                            // Inventory
                            div {
                                class: "flex items-center gap-3",
                                MaterialIcon {
                                    name: "storage",
                                    size: 24
                                },
                                p {
                                    class: "text-md font-medium",
                                    {format!("Inventory: {}", resp.total_transactions)}
                                }
                            },

                            // Price
                            div {
                                class: "flex items-center gap-3",
                                MaterialIcon {
                                    name: "attach_money",
                                    size: 24
                                },
                                p {
                                    class: "text-md font-medium",
                                    {format!("Price: ${:.2}", resp.total_price)}
                                }
                            }
                        }
                    },
                    None => rsx! {
                        div {
                            class: "text-center text-gray-500 dark:text-gray-400",
                            "Loading dogs..."
                        }
                    },
                },

                if let Some(min) = &*min.read_unchecked() {
                    if !min.is_empty() {
                            h2 {
                                class: "text-2xl font-semibold mt-8 mb-4",
                                "Items under Minimum"
                            },
                            div {
                                class: "space-y-3",
                                for item in min {
                                    div {
                                        class: "\
                                            w-full flex items-center justify-between bg-white dark:bg-gray-800 \
                                            shadow rounded-lg px-4 py-3",

                                        div {
                                            class: "flex items-center gap-2",
                                            MaterialIcon {
                                                name: "warning",
                                                size: 20
                                            },
                                            p {
                                                class: "font-medium",
                                                {format!("{} under minimum", item.item_variant)}
                                            }
                                        },

                                        p {
                                            class: "text-sm text-gray-600 dark:text-gray-400",
                                            {format!("Needs {} more.", item.need)}
                                        }
                                    }
                                }
                        }
                    }
                }

                if let Some(expired) = &*expired.read_unchecked() {
                    if !expired.is_empty() {
                            h2 {
                                class: "text-2xl font-semibold mt-8 mb-4",
                                "Expired Items"
                            },
                            div {
                                class: "space-y-4",
                                for item in expired {
                                    TransactionCard { t: item.clone() }
                                }
                            }
                    }
                }
            }
        }
    }
}
