use serde::{Deserialize, Serialize};
use web_sys::window;

pub fn save_to_local_storage_str(key: &str, value: &str) {
    let window = window().expect("no global `window` exists");
    let storage = window.local_storage().unwrap().unwrap();
    storage.set_item(key, value).unwrap();
}

pub fn load_from_local_storage_str(key: &str) -> Option<String> {
    let window = window().expect("no global `window` exists");
    let storage = window.local_storage().unwrap().unwrap();
    storage.get_item(key).unwrap()
}

pub fn save_to_local_storage<T: Serialize>(key: &str, value: T) {
    let val = serde_json::to_string(&value).unwrap();
    save_to_local_storage_str(key, &val);
}

pub fn load_from_local_storage<T: for<'a> Deserialize<'a>>(key: &str) -> Option<T> {
    let val = load_from_local_storage_str(key)?;
    serde_json::from_str(&val).ok()
}
